"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const requests_1 = tslib_1.__importDefault(require("../requests"));
const utils_1 = require("../utils");
const genericSteps_1 = require("./genericSteps");
// Step Constant config
// This won't change dynamically
const constConfig = {
    id: 'hubsteps',
    name: 'Hub Steps',
    description: 'Sets up the hub accounts',
    ignoreFailure: true,
};
// Define steps here
const stepGenerator = (config) => {
    return [
        {
            name: 'setup `HUB_MULTILATERAL_SETTLEMENT` account',
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postHubAccount(config.urls.centralLedgerAdmin, {
                body: {
                    type: "HUB_MULTILATERAL_SETTLEMENT",
                    currency: config.currency
                }
            }))
        },
        {
            name: 'setup `HUB_RECONCILIATION` account',
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postHubAccount(config.urls.centralLedgerAdmin, {
                body: {
                    type: "HUB_RECONCILIATION",
                    currency: config.currency
                }
            }))
        },
        {
            name: 'create settlement model `DEFERREDNET`',
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postSettlementModel(config.urls.centralLedgerAdmin, {
                body: {
                    name: `DEFERREDNET`,
                    settlementGranularity: `NET`,
                    settlementInterchange: `MULTILATERAL`,
                    settlementDelay: `DEFERRED`,
                    requireLiquidityCheck: true,
                    ledgerAccountType: `POSITION`,
                    autoPositionReset: true,
                    currency: config.currency,
                    settlementAccountType: `SETTLEMENT`,
                }
            }))
        },
        {
            name: 'setup `SETTLEMENT_TRANSFER_POSITION_CHANGE_EMAIL`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postHubEndpoints(config.urls.centralLedgerAdmin, {
                body: {
                    type: "SETTLEMENT_TRANSFER_POSITION_CHANGE_EMAIL",
                    value: 'email@example.com'
                }
            }))
        },
        {
            name: 'setup `NET_DEBIT_CAP_ADJUSTMENT_EMAIL`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postHubEndpoints(config.urls.centralLedgerAdmin, {
                body: {
                    type: "NET_DEBIT_CAP_ADJUSTMENT_EMAIL",
                    value: 'email@example.com'
                }
            }))
        },
        {
            name: 'setup `NET_DEBIT_CAP_THRESHOLD_BREACH_EMAIL`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postHubEndpoints(config.urls.centralLedgerAdmin, {
                body: {
                    type: "NET_DEBIT_CAP_THRESHOLD_BREACH_EMAIL",
                    value: 'email@example.com'
                }
            }))
        }
    ];
};
const hubsteps = (config) => new genericSteps_1.GenericSteps(constConfig, config, stepGenerator);
exports.default = hubsteps;
//# sourceMappingURL=hubSteps.js.map